@@ -76,6 +76,10 @@
 #undef HAVE_DL_DLOPEN
 #undef HAVE_DLD_DLD_LINK
 
+#undef USE_SHM_COPROCESSING
+
+#undef IPC_RMID_DEFERRED_RELEASE
+
 @BOTTOM@
 
 #endif /*G10_CONFIG_H*/
